==> haskell-keys-3.12.2-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-1OCiWYkohvYELfOrux87tD
key: keys-3.12.2-1OCiWYkohvYELfOrux87tD
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: 0b3a8c35924b3c022c2a504c89c33fda
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-1OCiWYkohvYELfOrux87tD
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-4oKFRzjdJyn9LPwjAsvqPG
    containers-0.6.0.1 free-5.1.2-9K5ZNbMJfrIC6OAtSxxaEc
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.2-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.12.2
id: keys-3.12.2-EDoNzDLf3oCJPODpSS2Xv3
key: keys-3.12.2-EDoNzDLf3oCJPODpSS2Xv3
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.
    .
    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.
category: Data Structures, Containers
abi: 683a4daa6ba52122cb1d8c8bd3f9a0b9
exposed: True
exposed-modules:
    Data.Key
import-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/keys-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/keys-3.12.2
hs-libraries: HSkeys-3.12.2-EDoNzDLf3oCJPODpSS2Xv3
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-4oKFRzjdJyn9LPwjAsvqPG
    containers-0.6.0.1 free-5.1.2-5scvljJ3PA2Kh8bwj5YT3D
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.3-JExo6frukwyAb0JHcgR6Sx
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
